==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPinColumnCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnCancellableEventArgsDetailDescriptionMetadata } from "./WebPinColumnCancellableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDescription } from "./WebPinColumnCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPinColumnCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnCancellableEventArgsDescriptionMetadata.a == null) {
                WebPinColumnCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnCancellableEventArgsDescriptionMetadata.c(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPinColumnCancellableEventArgsDetail");
        }
        static d(a) {
            WebPinColumnCancellableEventArgsDescriptionMetadata.b(a);
            a.ad("WebPinColumnCancellableEventArgs", () => new WebPinColumnCancellableEventArgsDescription());
            a.ac("WebPinColumnCancellableEventArgs", WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPinColumnCancellableEventArgsDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDescriptionMetadata, 'WebPinColumnCancellableEventArgsDescriptionMetadata');
    WebPinColumnCancellableEventArgsDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPinColumnCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnCancellableEventArgsDetailDescriptionMetadata } from "./WebPinColumnCancellableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDescription } from "./WebPinColumnCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPinColumnCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPinColumnCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPinColumnCancellableEventArgsDescriptionMetadata.a == null) {
                WebPinColumnCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPinColumnCancellableEventArgsDescriptionMetadata.c(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPinColumnCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPinColumnCancellableEventArgsDetail");
        }
        static d(a) {
            WebPinColumnCancellableEventArgsDescriptionMetadata.b(a);
            a.ae("WebPinColumnCancellableEventArgs", () => new WebPinColumnCancellableEventArgsDescription());
            a.ad("WebPinColumnCancellableEventArgs", WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPinColumnCancellableEventArgsDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDescriptionMetadata, 'WebPinColumnCancellableEventArgsDescriptionMetadata');
    WebPinColumnCancellableEventArgsDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDescriptionMetadata;
})();
